package at.jku.fim.datalinksimulation.layer1.wire.damagedwire;

import java.util.Iterator;

import at.jku.fim.datalinksimulation.layer1.data.RawData;
import at.jku.fim.datalinksimulation.layer1.wire.StandardWire;
import at.jku.fim.datalinksimulation.layer1.wire.WireConnector;

/**
 * <p>Title: OSI Simulation Framework</p>
 * <p>Copyright: (c) 2004-05</p>
 * <p>Company: FIM@JKU, www.fim.uni-linz.ac.at</p>
 * @author Andreas Putzinger
 * @version $Id: DamagedWire.java,v 1.1 2005/10/27 13:10:07 aputzinger Exp $
 */

public class DamagedWire extends StandardWire {

    /** the strategy implementation used to "confuse" data  */
    protected DamagingStrategy damagingStrategy = null;

    /** if value is set to true, damaging is performed */
    protected boolean damagingEnabled = true;

    /**
     * Constructor
     * @param strategy Inital damaging strategy; damaging is enabled by default
     */
    public DamagedWire(DamagingStrategy strategy) {
        super();
        setDamagingStrategy(strategy);
    }

    /*
	 * (non-Javadoc)
	 * 
	 * @see at.jku.fim.datalinksimulation.layer1.wire.Wire#send(at.jku.fim.datalinksimulation.data.RawData,
	 *      java.util.Vector)
	 */
    public void send(WireConnector sender, RawData data) {
        // do damaging here!
        if (damagingStrategy != null && damagingEnabled) {
            data = damagingStrategy.damageData(data);
        	// data now contains probably damaged data!
        }

        // if damaging strategy has eaten up package, do not inform connected devices
        if (data == null)
            return;
        
        // inform connected network components
        Iterator it = connectors.iterator();
        while (it.hasNext()) {
            WireConnector observer = (WireConnector) it.next();
            if (sender == null || !sender.equals(observer))
            	observer.informAboutDataOnWire(this, (RawData) data.clone());
        }
    }

    /**
     * @return Returns current active damaging strategy
     */
    public DamagingStrategy getDamagingStrategy() {
        return damagingStrategy;
    }

    /**
     * Set a new damaging strategy
     * @param damagingStrategy New damaging strategy or null
     */
    public void setDamagingStrategy(DamagingStrategy damagingStrategy) {
        this.damagingStrategy = damagingStrategy;
    }

    /**
     * @return Returns wheter damaging is currently enabled or not
     */
    public boolean isDamagingEnabled() {
        return damagingEnabled;
    }

    /**
     * Enable or disable data damaging
     * @param damagingEnabled Switch
     */
    public void setDamagingEnabled(boolean damagingEnabled) {
        this.damagingEnabled = damagingEnabled;
    }

}