package at.jku.fim.datalinksimulation.layer2.filters;

import at.jku.fim.datalinksimulation.layer1.data.RawData;
import at.jku.fim.datalinksimulation.layer2.protocols.EasyL2FrameData;
import at.jku.fim.datalinksimulation.layer2.protocols.EasyL2Utils;
import at.jku.fim.datalinksimulation.networkstack.NetworkStack;
import at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters;
import at.jku.fim.datalinksimulation.networkstack.incoming.DecodingNetworkFilter;
import at.jku.fim.datalinksimulation.utils.Logger;

/**
 * <p>Title: OSI Simulation Framework</p>
 * <p>Copyright: (c) 2004-05</p>
 * <p>Company: FIM@JKU, www.fim.uni-linz.ac.at</p>
 * @author Andreas Putzinger
 * @version $Id: EasyL2DecodingFilter.java,v 1.1 2005/10/27 13:10:07 aputzinger Exp $
 */

public class EasyL2DecodingFilter implements DecodingNetworkFilter {

    /*
     *  (non-Javadoc)
     * @see at.jku.fim.datalinksimulation.networkstack.NetworkFilter#getFilterOSILayer()
     */
    public int[] getFilterOSILayer() {
        int[] result = new int[1];
        result[0] = OSI_LAYER_2;
        return result;
    }

    /*
     *  (non-Javadoc)
     * @see at.jku.fim.datalinksimulation.networkstack.DecodingNetworkFilter#decode(at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters, at.jku.fim.datalinksimulation.data.RawData, at.jku.fim.datalinksimulation.utils.Logger)
     */
    public RawData decode(NetworkStackParameters params, RawData data,
            Logger logger) {
        EasyL2FrameData l2content = EasyL2Utils.interpretRawData(data,
                logger);
        if (l2content == null)
            return null;
        logger.log(l2content.toString());
        data.setRawDataBulk(l2content.getData());
        params.setParameter(2, "easyl2content", l2content);
        params.setParameter(NetworkStackParameters.GLOBAL_PARAMETER,
                NetworkStack.NETWORK_PARAM_SENDER_ADDRESS, new Integer(
                        l2content.getSource()));
        params.setParameter(NetworkStackParameters.GLOBAL_PARAMETER,
                NetworkStack.NETWORK_PARAM_RECEIVER_ADDRESS, new Integer(
                        l2content.getDestination()));
        return data;
    }

    /*
     *  (non-Javadoc)
     * @see at.jku.fim.datalinksimulation.networkstack.DecodingNetworkFilter#getDescription()
     */
    public String getDescription() {
        return "RawData to EasyL2 interpretation filter";
    }

}