package at.jku.fim.datalinksimulation.layer2.filters;

import at.jku.fim.datalinksimulation.layer1.data.RawData;
import at.jku.fim.datalinksimulation.layer2.protocols.EasyL2FrameData;
import at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters;
import at.jku.fim.datalinksimulation.networkstack.incoming.DecodingNetworkFilter;
import at.jku.fim.datalinksimulation.networkstack.incoming.IncomingNetworkStack;
import at.jku.fim.datalinksimulation.utils.Logger;

/**
 * <p>Title: OSI Simulation Framework</p>
 * <p>Copyright: (c) 2004-05</p>
 * <p>Company: FIM@JKU, www.fim.uni-linz.ac.at</p>
 * @author Andreas Putzinger
 * @version $Id: EasyL2DestinationFilter.java,v 1.1 2005/10/27 13:10:07 aputzinger Exp $
 */

public class EasyL2DestinationFilter implements DecodingNetworkFilter {

    /*
     *  (non-Javadoc)
     * @see at.jku.fim.datalinksimulation.networkstack.NetworkFilter#getFilterOSILayer()
     */
    public int[] getFilterOSILayer() {
        int[] result = new int[1];
        result[0] = OSI_LAYER_2;
        return result;
    }

    /*
     *  (non-Javadoc)
     * @see at.jku.fim.datalinksimulation.networkstack.DecodingNetworkFilter#decode(at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters, at.jku.fim.datalinksimulation.data.RawData, at.jku.fim.datalinksimulation.utils.Logger)
     */
    public RawData decode(NetworkStackParameters params, RawData data,
            Logger logger) {
        Object obj = params.getParameter(2, "easyl2content");
        if (obj == null) {
            logger.log("No EasyL2 information found; Blocking package!");
            return null;
        }
        EasyL2FrameData l2content = (EasyL2FrameData) obj;
        int destAddress = l2content.getDestination();
        obj = params.getParameter(NetworkStackParameters.GLOBAL_PARAMETER,
                IncomingNetworkStack.NETWORK_PARAM_STATION_ID);
        if (obj == null) {
            logger
                    .log("Cannot determine this station's station ID; Blocking package!");
            return null;
        }
        int stationId = -1;
        try {
            stationId = ((Integer) obj).intValue();
        } catch (Exception e) {
        }
        if (stationId < 0 || stationId != destAddress) {
            logger
                    .log("This station is not right destination for package; Blocking package!");
            return null;
        }
        logger
                .log("This station is right destination for package; let data pass ...");
        return data;
    }

    /*
     *  (non-Javadoc)
     * @see at.jku.fim.datalinksimulation.networkstack.DecodingNetworkFilter#getDescription()
     */
    public String getDescription() {
        return "Only packages for this network station may pass";
    }

}