package at.jku.fim.datalinksimulation.layer2.filters;

import java.util.BitSet;

import at.jku.fim.datalinksimulation.layer1.data.RawData;
import at.jku.fim.datalinksimulation.layer2.protocols.EasyL2FrameData;
import at.jku.fim.datalinksimulation.layer2.protocols.EasyL2Utils;
import at.jku.fim.datalinksimulation.networkstack.NetworkStack;
import at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters;
import at.jku.fim.datalinksimulation.networkstack.outgoing.EncodingNetworkFilter;
import at.jku.fim.datalinksimulation.utils.CRCUtils;
import at.jku.fim.datalinksimulation.utils.ConversionUtils;
import at.jku.fim.datalinksimulation.utils.Logger;

/**
 * <p>Title: OSI Simulation Framework</p>
 * <p>Copyright: (c) 2004-05</p>
 * <p>Company: FIM@JKU, www.fim.uni-linz.ac.at</p>
 * @author Andreas Putzinger
 * @version $Id: EasyL2EncodingFilter.java,v 1.1 2005/10/27 13:10:07 aputzinger Exp $
 */

public class EasyL2EncodingFilter implements EncodingNetworkFilter {

    /*
	 * (non-Javadoc)
	 * 
	 * @see at.jku.fim.datalinksimulation.networkstack.EncodingNetworkFilter#encode(at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters,
	 *      at.jku.fim.datalinksimulation.data.RawData,
	 *      at.jku.fim.datalinksimulation.utils.Logger)
	 */
    public RawData encode(NetworkStackParameters params, RawData data,
            Logger logger) {
        EasyL2FrameData l2content = new EasyL2FrameData();
        l2content.setData(data.getRawDataBulk());
        Object receiver = params.getParameter(
                NetworkStackParameters.GLOBAL_PARAMETER,
                NetworkStack.NETWORK_PARAM_RECEIVER_ADDRESS);
        Object sender = params.getParameter(
                NetworkStackParameters.GLOBAL_PARAMETER,
                NetworkStack.NETWORK_PARAM_SENDER_ADDRESS);
        if (receiver != null && (receiver instanceof Integer)) {
            int receiverId = ((Integer) receiver).intValue();
            l2content.setDestination(receiverId);
        }
        if (sender != null && (sender instanceof Integer)) {
            int senderId = ((Integer) sender).intValue();
            l2content.setSource(senderId);
        }

        RawData frame = EasyL2Utils.createFrame(l2content, logger);
        int[] rd = frame.getRawDataBulk();
        BitSet bs = ConversionUtils.createBitSet(rd);
        CRCUtils.insertCrc(bs, logger);
        rd = ConversionUtils.createFrame(bs, rd.length);
        frame.setRawDataBulk(rd);

        return frame;
    }

    /*
	 * (non-Javadoc)
	 * 
	 * @see at.jku.fim.datalinksimulation.networkstack.NetworkFilter#getFilterOSILayer()
	 */
    public int[] getFilterOSILayer() {
        int[] layers = new int[1];
        layers[0] = OSI_LAYER_2;
        return layers;
    }

    /*
	 * (non-Javadoc)
	 * 
	 * @see at.jku.fim.datalinksimulation.networkstack.EncodingNetworkFilter#getDescription()
	 */
    public String getDescription() {
        return "Construct EasyL2 frame";
    }

}