package at.jku.fim.datalinksimulation.layer2.protocols;

/**
 * <p>Title: OSI Simulation Framework</p>
 * This class is a representation of the data contained in an EasyL2 Frame.
 * Using methods in class EasyL2Utils it can be converted to RawData and back.
 * <p>Copyright: (c) 2004-05</p>
 * <p>Company: FIM@JKU, www.fim.uni-linz.ac.at</p>
 * @author Andreas Putzinger
 * @version $Id: EasyL2FrameData.java,v 1.1 2005/10/27 13:10:11 aputzinger Exp $
 */

public class EasyL2FrameData {

    // Content of preamble; must always be 0x77
    private int preamble;

    // source address of frame (16 bit)
    private int source;

    // destination address of frame (16 bit) 
    private int destination;

    // overall size of frame
    private int size;

    // L3 data
    private int[] data = new int[0];

    // 4 byte CRC
    private int[] crc = new int[4];

    /**
     * @return Returns the crc.
     */
    public int[] getCrc() {
        return crc;
    }

    /**
     * @param crc The crc to set.
     */
    public void setCrc(int[] crc) {
        this.crc = crc;
    }

    /**
     * @return Returns the data.
     */
    public int[] getData() {
        return data;
    }

    /**
     * @param data The data to set.
     */
    public void setData(int[] data) {
        this.data = data;
    }

    /**
     * @return Returns the destination.
     */
    public int getDestination() {
        return destination;
    }

    /**
     * @param destination The destination to set.
     */
    public void setDestination(int destination) {
        this.destination = destination;
    }

    /**
     * @return Returns the preamble.
     */
    public int getPreamble() {
        return preamble;
    }

    /**
     * @param preamble The preamble to set.
     */
    public void setPreamble(int preamble) {
        this.preamble = preamble;
    }

    /**
     * @return Returns the size.
     */
    public int getSize() {
        return size;
    }

    /**
     * @param size The size to set.
     */
    public void setSize(int size) {
        this.size = size;
    }

    /**
     * @return Returns the source.
     */
    public int getSource() {
        return source;
    }

    /**
     * @param source The source to set.
     */
    public void setSource(int source) {
        this.source = source;
    }
    
    /*
     *  (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    public String toString() {
        StringBuffer str = new StringBuffer();
        str.append("\n++++ EasyL2 frame data ++++\n");
        str.append("Preamble:         " + preamble + "\n");
        str.append("Destination ID:   " + destination + "\n");
        str.append("Source ID:        " + source + "\n");
        str.append("Frame size:       " + size + "\n");
        str.append("CRC:              ");

        if (crc == null)
            str.append("<not set>");
        else
            for (int i = 0; i < crc.length; i++)
                str.append("" + crc[i] + " ");
        str.append("\n");
        str.append("Data:             ");
        if (data == null)
            str.append("<not set>");
        else
            for (int i = 0; i < data.length; i++)
                str.append("" + data[i] + " ");
        str.append("\n++++ END EasyL2 frame data ++++\n");
        return str.toString();
    }
}