package at.jku.fim.datalinksimulation.layer7.enduser;

import java.awt.event.ActionEvent;

import at.jku.fim.datalinksimulation.layer1.data.RawData;
import at.jku.fim.datalinksimulation.layer7.Application;
import at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters;
import at.jku.fim.datalinksimulation.scenario.gui.SenderPanel;
import at.jku.fim.datalinksimulation.utils.ConversionUtils;
import at.jku.fim.datalinksimulation.utils.Logger;

/**
 * <p>Title: OSI Simulation Framework</p>
 * <p>Copyright: (c) 2004-05</p>
 * <p>Company: FIM@JKU, www.fim.uni-linz.ac.at</p>
 * @author Andreas Putzinger
 * @version $Id: TextSendingApplication.java,v 1.1 2005/10/27 13:10:11 aputzinger Exp $
 */

public class TextSendingApplication extends Application {

    /**
     * Associated GUI
     */
    protected SenderPanel gui = null;

    /**
     * Station ID of host this application is running on
     */
    protected int stationID;

    /**
     * Associated Logger component
     */
    protected Logger logger;

    /**
     * Constructor
     * @param gui Associated GUI
     * @param stationId Station ID of host
     */
    public TextSendingApplication(SenderPanel gui, int stationId) {
    	super(null);
        this.stationID = stationId;
        logger = new Logger("Text Sending Application on station " + stationId);
        setGui(gui);
    }

    /**
     * Constructor
     * @param stationId Station ID of host
     */
    public TextSendingApplication(int stationId) {
        this(null, stationId);
    }

    protected void showMessage(String str) {
        gui.getMessageLabel().setText(str);
    }

    /**
     * This method is called whenever the Send-Button in the GUI is pressed
     * @param e 
     */
    public void sendButtonPressed(ActionEvent e) {
        // check for valid input
        String recString = gui.getReceiverId().getText();
        int receiverId = -1;
        if (recString != null && recString.length() > 0) {
            try {
                int temp = Integer.parseInt(recString);
                if (temp >= 0) {
                    receiverId = temp;
                }
            } catch (Exception ex) {
            }
        }

        // failure - invalid input!
        if (receiverId < 0) {
            showMessage("Invalid receiver; numeric values only");
            return;
        }

        String data = gui.getPlainText().getText();
        if (data == null || data.length() == 0 || data.length() > 100) {
            showMessage("Invalid text; 1<=length<=100");
            return;
        }

        logger.log("Sending text to station " + receiverId);
        logger.log("Plaintext: <" + data + ">");
        logger.log("Hex: <" + ConversionUtils.stringToHex(data) + ">");

        int[] contents = new int[data.length()];
        RawData rd = new RawData(null);
        for (int i = 0; i < data.length(); i++) {
            contents[i] = data.charAt(i);
            if (contents[i] < 0 || contents[i] > 255)
                contents[i] = 0;
        }
        rd.setRawDataBulk(contents);
        getNetworkStack().sendToWorld(new Integer(receiverId), rd, null); 
        showMessage("Text successfully sent");
        gui.getPlainText().setText("");
        gui.getReceiverId().setText("");
        gui.getHexText().setText("");
    }

    /*
     *  (non-Javadoc)
     * @see at.jku.fim.datalinksimulation.networkstack.IncomingNetworkStackObserver#informAboutNewData(at.jku.fim.datalinksimulation.networkstack.NetworkStackParameters, at.jku.fim.datalinksimulation.data.RawData)
     */
    public void informAboutNewData(NetworkStackParameters params, RawData data) {
    }

    /**
     * @return Returns associated GUI component
     */
    public SenderPanel getGui() {
        return gui;
    }

    /**
     * Set associated GUI component
     * @param gui Associated GUI
     */
    public void setGui(SenderPanel gui) {
        this.gui = gui;
        if (gui != null) {
            gui.setStationID("" + this.stationID);
        }
    }
    
	/**
	 * @param parent Parent logger
	 */
	public void setParentLogger(Logger parent) {
		parent.addChildLogger(logger);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see at.jku.fim.datalinksimulation.layer7.Application#getLogger()
	 */
	public Logger getLogger() {
		return logger;
	}

}